from typing import Dict

from fastapi import APIRouter, Response

from .Observatory import ASL_OBSERVATORY_INDEX


router = APIRouter()


@router.get(
    "/variometers/",
    description="Information regarding available variometers",
)
def get_observatories() -> Dict:
    return {
        "type": "FeatureCollection",
        "features": [
            ASL_OBSERVATORY_INDEX[id].geojson() for id in ASL_OBSERVATORY_INDEX.keys()
        ],
    }


@router.get(
    "/variometers/{id}",
    description="Search variometers by 3-5 letter observatory code",
)
async def get_observatory_by_id(id: str) -> Dict:
    try:
        return ASL_OBSERVATORY_INDEX[id].geojson()
    except KeyError:
        return Response(status_code=404)
