import os

from ..edge import EdgeFactory, MiniSeedFactory


def get_edge_factory(
    data_type="variation",
    host=os.getenv("EDGE_HOST", "127.0.0.1"),
    interval="second",
    input_port=os.getenv("INPUT_EDGE_PORT", None),
    output_port=os.getenv("OUTPUT_EDGE_PORT", None),
    **kwargs
) -> EdgeFactory:
    if input_port is None:
        input_port = 2060
    if output_port is None:
        output_port = 7981
    return EdgeFactory(
        host=host,
        interval=interval,
        type=data_type,
        port=input_port,
        write_port=output_port,
        **kwargs
    )


def get_miniseed_factory(
    data_type="variation",
    host=os.getenv("EDGE_HOST", "127.0.0.1"),
    interval="second",
    input_port=os.getenv("INPUT_MINISEED_PORT", None),
    output_port=os.getenv("OUTPUT_MINISEED_PORT", None),
    **kwargs
) -> MiniSeedFactory:
    if input_port is None:
        input_port = 2061
    if output_port is None:
        output_port = 7974
    return MiniSeedFactory(
        host=host,
        interval=interval,
        type=data_type,
        port=input_port,
        write_port=output_port,
        **kwargs
    )
